@@ -2,10 +2,10 @@
 
 import argparse
 import logging
-import pprint
 import sys
+from collections.abc import Mapping, Sequence
 from pathlib import Path
-from typing import Sequence
+from typing import Callable
 
 from . import __version__
 from .cycles import detect_cycles
@@ -102,12 +102,9 @@ def main() -> int:
     }
 
     if _debug():
-        # Avoid execution of pprint.pformat call if not debug
         logger.debug(
-            "Imports by module: %s",
-            pprint.pformat(
-                {str(ibm.name): [str(m.name) for m in ms] for ibm, ms in imports_by_module.items()}
-            ),
+            "Imports by module:\n%s",
+            "\n".join(_make_readable_imports_by_module(imports_by_module)),
         )
 
     logger.info("Detect import cycles with strategy %s", args.strategy)
@@ -116,18 +113,16 @@ def main() -> int:
     logger.info("Sort import cycles")
     sorted_cycles = sorted(unsorted_cycles, key=lambda t: (len(t), t[0].name))
 
-    logger.info("Close cycles")
-    import_cycles: Sequence[tuple[Module, ...]] = [
-        ((cycle[-1],) + cycle) for cycle in sorted_cycles
-    ]
-
-    sys.stderr.write(f"Found {len(import_cycles)} import cycles\n")
-
-    _log_or_show_cycles(args.verbose, import_cycles)
+    sys.stderr.write(f"Found {len(sorted_cycles)} import cycles\n")
+    _log_or_show_cycles(args.verbose, sorted_cycles)
 
     if args.graph:
-        logger.info("Make graph")
-        make_graph(outputs_filepaths.graph, args.strategy, import_cycles)
+        logger.info("Close cycle and make graph")
+        make_graph(
+            outputs_filepaths.graph,
+            args.strategy,
+            [((cycle[-1],) + cycle) for cycle in sorted_cycles],
+        )
 
     return len(unsorted_cycles) > args.threshold
 
@@ -142,23 +137,44 @@ def main() -> int:
 #   '----------------------------------------------------------------------'
 
 
+def _make_readable_imports_by_module(
+    imports_by_module: Mapping[Module, Sequence[Module]]
+) -> Sequence[str]:
+    lines = []
+    for ibm, ms in imports_by_module.items():
+        if ms:
+            lines.append(f"  {ibm.name} imports: {', '.join(str(m.name) for m in ms)}")
+    return lines
+
+
+def _make_readable_cycles(
+    line_handler: Callable[[int, tuple[Module, ...]], Sequence[str]],
+    sorted_cycles: Sequence[tuple[Module, ...]],
+) -> list[str]:
+    return [
+        line for nr, ic in enumerate(sorted_cycles, start=1) for line in line_handler(nr, ic) if ic
+    ]
+
+
 def _log_or_show_cycles(
     verbose: bool,
-    import_cycles: Sequence[tuple[Module, ...]],
+    sorted_cycles: Sequence[tuple[Module, ...]],
 ) -> None:
     if verbose:
-        for nr, import_cycle in enumerate(import_cycles, start=1):
-            sys.stderr.write(f"  {nr}: {[str(ic.name) for ic in import_cycle]}\n")
+        for line in _make_readable_cycles(
+            lambda nr, ic: [f"  Cycle {nr}:"] + [f"   {m.name}" for m in ic],
+            sorted_cycles,
+        ):
+            sys.stderr.write(f"{line}\n")
 
     if _debug():
-        # Avoid execution of pprint.pformat call if not debug
         logger.debug(
-            "Import cycles: %s",
-            pprint.pformat(
-                {
-                    nr: [str(p.name) for p in import_cycle]
-                    for nr, import_cycle in enumerate(import_cycles, start=1)
-                }
+            "Import cycles:\n%s",
+            "\n".join(
+                _make_readable_cycles(
+                    lambda nr, ic: [f"  Cycle {nr}: {' > '.join(str(m.name) for m in ic)}"],
+                    sorted_cycles,
+                )
             ),
         )
 
