@@ -4,7 +4,7 @@ from pathlib import Path
 from typing import Iterator, NamedTuple, Sequence
 
 
-def iter_python_files(project_path: Path, packages: Sequence[str]) -> Iterator[Path]:
+def iter_python_files(project_path: Path, packages: Sequence[Path]) -> Iterator[Path]:
     if packages:
         for pkg in packages:
             yield from (p.resolve() for p in (project_path / pkg).glob("**/*.py"))
@@ -19,13 +19,13 @@ class OutputsFilepaths(NamedTuple):
     graph: Path
 
 
-def get_outputs_filepaths(project_path: Path, packages: Sequence[str]) -> OutputsFilepaths:
+def get_outputs_filepaths(project_path: Path, packages: Sequence[Path]) -> OutputsFilepaths:
     target_dir = Path.home() / Path(".local", "py_import_cycles", "outputs")
     target_dir.mkdir(parents=True, exist_ok=True)
 
     filename_parts = list(project_path.parts[1:])
     if packages:
-        filename_parts.extend(sorted(packages))
+        filename_parts.extend(sorted(["-".join(p.parts) for p in packages]))
 
     filename = Path("-".join(filename_parts).replace(".", "-"))
 
